<?php
/**
 * CUSTOM MESSAGING PROCESSOR
 * This class extends the factory email handler class
 * Courtesy support for this class is limited to Standard and higher accounts.
 * For information about this class extention, please review the associated 
 * support documentation.
 */
require_once INCLICK_CLASSES_DIR . "/messaging/EmailMessageProcessor.php";

class CustomEmailMessageProcessor extends EmailMessageProcessor
{
	/**
	 * Sets the signature line for all email messages sent
	 *
	 * @return $signature
	 */
	function getSignature()
	{
		$signature = "
Thanks!

$this->network_name  
$this->system_email 
$this->network_url"."index.php"; 

		return $signature;
	}

	/**
	 * Send the New Advertiser Welcome message.
	 *
	 * @param $advertiser_user
	 * @return unknown
	 */
	function sendAdvertiserWelcomeEmail($advertiser_user)
	{
		$username = $advertiser_user->getUsername();
		$email_address = $advertiser_user->getEmailAddress();

		$message = $this->getSalutationForUserAccount($advertiser_user);
		$message .= "Welcome!

You've just joined the $this->network_name advertising network. We're looking forward to helping you make the most of your marketing efforts.
			
Your account is now ready and available for use.  To log in, visit: " . $this->network_url . "index_client.php . We're currently in the process of approving your ad(s) and you'll be notified when they're approved.

Your Username:  $username
			
Once again, welcome to our network.";			
		return $this->_internal_sendMessageToUserAccount($advertiser_user, "New Account Information", $message);
	}
	/**
	 * Send the Password Reset email message to the user
	 *
	 * @param unknown_type $user_account
	 * @param unknown_type $new_password
	 */
	function sendPasswordResetEmail($user_account, $new_password)
	{
		$username = $user_account->getUsername();
		$account_type = "Advertiser";
		$account_id = $user_account->getUserID();

		if ($user_account->getAccountTypeCode() == $user_account->ACCOUNT_TYPE_PUBLISHER)
		{
			$account_type = "Publisher";
		}

		$message = $this->getSalutationForUserAccount($user_account);
		$message .= "Here is your Username and Temporary Password. These credentials will be needed to access your $account_type Control Panel.  You will be asked to change this temporary password the next time you access your account.

Username: $username
Temporary Password: $new_password
Account Type:  $account_type 
Customer ID:  $account_id

Login URL:  $this->network_url" . "index_client.php

Please drop us a line at $this->system_email if you have any questions.";

		$this->_internal_sendMessageToUserAccount($user_account, "$account_type Login Assistance", $message);
	}

	/**
	 * Send the Unable To Find Email Address in system message (password reset workflow
	 *
	 * @param unknown_type $email_address
	 */
	function sendAccountNotFoundEmail($email_address)
	{
		$message = "Hello,
			
We're sorry, we were not able to find a user account for the email address provided: $email_address
			
Is it possible you used a different address?

If you have questions, please drop us a line at $this->system_email.
";
		$this->_internal_sendMessage($email_address, $email_address, "Login Assistance - Account Not Found", $message);
	}



	/**
	 * Send Pasword has Changed notice to account email address.
	 *
	 * @param unknown_type $user_account
	 */
	function sendPasswordChangedEmail($user_account)
	{
		$email_address = $user_account->getEmailAddress();

		$message = $this->getSalutationForUserAccount($user_account);
		$message .= "This is a security notice message!  This message is sent to inform you that the password for your $this->network_name account was recently changed.

Please ignore this message if you changed your account password recently.  If you did not perform this password change, please contact the network administrator at: $this->system_email as your account may have been compromised.";

		$this->_internal_sendMessageToUserAccount($user_account, "Password Changed Notice", $message);
	}

	/**
	 * Email sent to user regarding a credit card decline for automatic billing
	 *
	 * @param unknown_type $user_account
	 * @return unknown
	 */
	function sendRebillingDeclinedEmail($user_account)
	{
		$message = $this->getSalutationForUserAccount($user_account);
		$message .= "sendRebillingDeclinedEmail - Good news, bad news!

The good: We have delivered so much targeted traffic to your site that your account funds are running low.

However (bad news), your credit card was unfortunately declined during our attempt to automatically fund your account.

We will resume sending you targeted traffic when you make another deposit to cover future clickthroughs to your site.  We are a pre-pay ad network and we recommend a deposit equal to or greater than one month's estimated charges or updating your Automatic Funding profile.

To add funds to your account please do the following:

Step 1.  Log in at: " . $this->network_url . "index_client.php

Step 2.  Select 'Add Funds' from the navigation menu

If you need help or have questions, drop us a line at $this->system_email.

We want to continue promoting your web site and hope to hear from you soon.";

		return $this->_internal_sendMessageToUserAccount($user_account, "Low Funds Notification", $message);
	}

	/**
	 * Message sent to advertisers that they have been rebilled for services
	 *
	 * @param unknown_type $user_account
	 * @param unknown_type $amount
	 * @return unknown
	 */
	function sendRebillingSuccessfulEmail($user_account, $amount)
	{
		$amount_string = sprintf("%1.02f", $amount);

		$message = $this->getSalutationForUserAccount($user_account);
		$message .= "Great news! Your $this->network_name advertisements have generated many clickthroughs to your site!  As a result of this traffic however, your account funds were running low.

In order to continue sending traffic to your site, we required a payment to cover future clickthroughs to your site.  Since you subscribed to our Automatic Funding feature, we have billed the credit card you placed on file for the amount of $$amount_string.

If you have any questions, feel free to drop us a line at $this->system_email.";

		return $this->_internal_sendMessageToUserAccount($user_account, "Rebilling Notification", $message);
	}

	/**
	 * Message sent to users when funds are low and the account is not subscribed to automatic funding.
	 *
	 * @param unknown_type $user_account
	 */
	function sendLowFundsEmail($user_account)
	{
		$message = $this->getSalutationForUserAccount($user_account);
		$message .= "As a result of the volume of targeted traffic we have delivered to your site, the funds in your account are running low. In order to prevent the interruption of the delivery of your campaigns, we recommend you make another deposit right away.

You can also sign up for our auto-billing feature if you would rather have your account funded automatically.  

To add funds to your account please do the following:

Step 1.  Log in at: " . $this->network_url . "index_client.php

Step 2.  Select 'Add Funds' from the navigation menu
      
We want to continue promoting your web site and hope to hear from you soon. If you have any questions, please contact $this->system_email.";

		$this->_internal_sendMessageToUserAccount($user_account, "Low Funds Notification", $message);

	}

	/**
	 * Message sent to advertiser when ad is declined and an email is to be sent with reason(s)
	 *
	 * @param unknown_type $user_account
	 * @param unknown_type $campaign
	 * @param unknown_type $hold_reason_list
	 * @param unknown_type $additional_notes
	 */
	function sendCampaignRequiresModificationWithReasonsEmail($user_account, $campaign, $hold_reason_list, $additional_notes)
	{
		$campaign_id = $campaign->getCampaignID();
		$campaign_name = $campaign->getName();

		$message = $this->getSalutationForUserAccount($user_account);
		$message .= "Unfortunately, one of your campaigns requires modification before it can be activated.

Campaign ID: $campaign_id
Name: " . $campaign_name . "\r\n\r\n";

		//THIS IS THE LIST OF REASONS THAT WERE SELECTED
		if (sizeof($hold_reason_list) > 0)
		{
			$message .= "Reasons: \r\n";

			for ($x = 0; $x < sizeof($hold_reason_list); $x++)
			{
				$message .= $hold_reason_list[$x]->getDescription() . " - " . $hold_reason_list[$x]->getSuggestion() . "\r\n\r\n";
			}
		}

		if (trim($additional_notes) != "")
		{
			$message .= "Editor Notes:\r\n";
			$message .= $additional_notes . "\r\n\r\n";
		}

		$message .= "
To update your campaign, please login at: $this->network_url" . "index_client.php";

		$this->_internal_sendMessageToUserAccount($user_account, "Campaign requires modification", $message);
	}

	/**
	 * Message sent to advertisers when an advertisement is approved with a notice
	 *
	 * @param unknown_type $user_account
	 * @param unknown_type $campaign
	 * @param unknown_type $additional_notes
	 */
	function sendCampaignApprovalEmail($user_account, $campaign, $additional_notes)
	{
		$message = $this->getSalutationForUserAccount($user_account);

		$message .= "This message is to inform you that one of your campaigns has been approved and will begin to show on our network.

Campaign ID: " . $campaign->getCampaignID() . "
Name: " . $campaign->getName();

		if (trim($additional_notes) != "")
		{
			$message .= "\r\n\r\nEditor Notes:\r\n";
			$message .= $additional_notes . "\r\n";
		}
		$this->_internal_sendMessageToUserAccount($user_account, "Campaign Approval Notification", $message);
	}
}
?>